==> easypost-api-client-6.0.0-rc1-sources.jar: com/easypost/service/OrderService.java <==
package com.easypost.service;

import com.easypost.exception.EasyPostException;
import com.easypost.http.Requestor;
import com.easypost.http.Requestor.RequestMethod;
import com.easypost.model.Order;
import com.easypost.model.Rate;
import com.easypost.utils.Utilities;

import java.util.HashMap;
import java.util.Map;

public class OrderService {
    private final EasyPostClient client;

    /**
     * OrderService constructor.
     * 
     * @param client The client object.
     */
    OrderService(EasyPostClient client) {
        this.client = client;
    }

    /**
     * Create an Order object from a map of paramters.
     *
     * @param params Map of parameters.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order create(final Map<String, Object> params) throws EasyPostException {
        Map<String, Object> wrappedParams = new HashMap<String, Object>();
        wrappedParams.put("order", params);

        return Requestor.request(RequestMethod.POST, Utilities.classURL(Order.class), wrappedParams, Order.class,
                client);
    }

    /**
     * Retrieve an Order object from the API.
     *
     * @param id ID of the Order to retrieve.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order retrieve(final String id) throws EasyPostException {
        return Requestor.request(RequestMethod.GET, Utilities.instanceURL(Order.class, id), null, Order.class, client);
    }

    /**
     * Get new rates for this Order.
     *
     * @param id The ID of order.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order newRates(final String id) throws EasyPostException {
        return this.newRates(id, null);
    }

    /**
     * Get new rates for this Order.
     *
     * @param id     The ID of order.
     * @param params Map of parameters.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order newRates(final String id, final Map<String, Object> params) throws EasyPostException {
        return Requestor.request(RequestMethod.GET, String.format("%s/rates",
                Utilities.instanceURL(Order.class, id)), params, Order.class, client);
    }

    /**
     * Buy this Order.
     *
     * @param id     The ID of order.
     * @param params Map of parameters.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order buy(final String id, final Map<String, Object> params) throws EasyPostException {
        return Requestor.request(RequestMethod.POST, String.format("%s/buy",
                Utilities.instanceURL(Order.class, id)), params, Order.class, client);
    }

    /**
     * Buy this Order.
     *
     * @param id   The ID of order.
     * @param rate Rate to buy.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order buy(final String id, final Rate rate) throws EasyPostException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("carrier", rate.getCarrier());
        params.put("service", rate.getService());

        return this.buy(id, params);
    }
}

==> easypost-api-client-6.2.0-sources.jar: com/easypost/service/OrderService.java <==
package com.easypost.service;

import com.easypost.exception.EasyPostException;
import com.easypost.http.Requestor;
import com.easypost.http.Requestor.RequestMethod;
import com.easypost.model.Order;
import com.easypost.model.Rate;
import com.easypost.utils.InternalUtilities;

import java.util.HashMap;
import java.util.Map;

public class OrderService {
    private final EasyPostClient client;

    /**
     * OrderService constructor.
     * 
     * @param client The client object.
     */
    OrderService(EasyPostClient client) {
        this.client = client;
    }

    /**
     * Create an Order object from a map of paramters.
     *
     * @param params Map of parameters.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order create(final Map<String, Object> params) throws EasyPostException {
        Map<String, Object> wrappedParams = new HashMap<String, Object>();
        wrappedParams.put("order", params);

        return Requestor.request(RequestMethod.POST, InternalUtilities.classURL(Order.class), wrappedParams,
                Order.class,
                client);
    }

    /**
     * Retrieve an Order object from the API.
     *
     * @param id ID of the Order to retrieve.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order retrieve(final String id) throws EasyPostException {
        return Requestor.request(RequestMethod.GET, InternalUtilities.instanceURL(Order.class, id), null, Order.class,
                client);
    }

    /**
     * Get new rates for this Order.
     *
     * @param id The ID of order.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order newRates(final String id) throws EasyPostException {
        return this.newRates(id, null);
    }

    /**
     * Get new rates for this Order.
     *
     * @param id     The ID of order.
     * @param params Map of parameters.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order newRates(final String id, final Map<String, Object> params) throws EasyPostException {
        return Requestor.request(RequestMethod.GET, String.format("%s/rates",
                InternalUtilities.instanceURL(Order.class, id)), params, Order.class, client);
    }

    /**
     * Buy this Order.
     *
     * @param id     The ID of order.
     * @param params Map of parameters.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order buy(final String id, final Map<String, Object> params) throws EasyPostException {
        return Requestor.request(RequestMethod.POST, String.format("%s/buy",
                InternalUtilities.instanceURL(Order.class, id)), params, Order.class, client);
    }

    /**
     * Buy this Order.
     *
     * @param id   The ID of order.
     * @param rate Rate to buy.
     * @return Order object.
     * @throws EasyPostException when the request fails.
     */
    public Order buy(final String id, final Rate rate) throws EasyPostException {
        Map<String, Object> params = new HashMap<String, Object>();
        params.put("carrier", rate.getCarrier());
        params.put("service", rate.getService());

        return this.buy(id, params);
    }
}
